@@ -288,7 +288,8 @@ requery_seq <- function(emuDBhandle,
     
     trSl = convert_queryResultToEmuRsegs(emuDBhandle, 
                                          timeRefSegmentLevel = timeRefSegmentLevel, 
-                                         filteredTablesSuffix = "", 
+                                         sessionPattern = ".*", 
+                                         bundlePattern = ".*", 
                                          queryStr = "FROM REQUERY", 
                                          calcTimes = calcTimes, 
                                          verbose = verbose)
@@ -568,7 +569,8 @@ requery_hier <- function(emuDBhandle,
                          secondLevelName = reqAttrDefLn, 
                          leftTableSuffix = origSeglistItemsTableSuffix, 
                          rightTableSuffix = reqLevelItemsTableSuffix, 
-                         filteredTablesSuffix = "", 
+                         sessionPattern = ".*", 
+                         bundlePattern = ".*",
                          preserveLeafLength = preserveLeafLength,
                          preserveAnchorLength = preserveAnchorLength,
                          verbose = verbose) # result written to lr_exp_res_tmp table
@@ -624,7 +626,8 @@ requery_hier <- function(emuDBhandle,
     
     trSl = convert_queryResultToEmuRsegs(emuDBhandle, 
                                          timeRefSegmentLevel = timeRefSegmentLevel, 
-                                         filteredTablesSuffix = "", 
+                                         sessionPattern = ".*", 
+                                         bundlePattern = ".*",
                                          queryStr = "FROM REQUERY", 
                                          calcTimes = calcTimes, 
                                          preserveAnchorLength = T,
