@@ -4,9 +4,12 @@ context("testing emuRtrackdata functions")
 
 dbName = "ae"
 
-path2orig = file.path(tempdir(), "emuR_demoData", paste0(dbName, emuDB.suffix))
+path2orig = file.path(tempdir(), 
+                      "emuR_demoData", 
+                      paste0(dbName, emuDB.suffix))
 path2testData = file.path(tempdir(), "emuR_testthat")
-path2db = file.path(path2testData, paste0(dbName, emuDB.suffix))
+path2db = file.path(path2testData, 
+                    paste0(dbName, emuDB.suffix))
 
 # extract internalVars from environment .emuR_pkgEnv
 internalVars = get("internalVars", envir = .emuR_pkgEnv)
@@ -14,17 +17,24 @@ internalVars = get("internalVars", envir = .emuR_pkgEnv)
 test_that("emuRtrackdata functions work", {
   # delete, copy and load
   unlink(path2db, recursive = T)
-  file.copy(path2orig, path2testData, recursive = T)
-  ae = load_emuDB(path2db, inMemoryCache = internalVars$testingVars$inMemoryCache, verbose = F)
+  file.copy(path2orig, 
+            path2testData, 
+            recursive = T)
+  ae = load_emuDB(path2db, 
+                  inMemoryCache = internalVars$testingVars$inMemoryCache, 
+                  verbose = F)
   
   
   ##############################
   test_that("correct classes are returned", {
     
-    sl = query(ae, "Phonetic=@|i:")
+    sl = query(ae, "Phonetic == @ | i:", 
+               resultType = "emuRsegs")
     td = get_trackdata(ae, 
                        seglist = sl, 
-                       ssffTrackName = 'fm', verbose = F)
+                       ssffTrackName = 'fm',
+                       resultType = "trackdata",
+                       verbose = F)
     
     newTd = create_emuRtrackdata(sl, td)
     
@@ -49,7 +59,8 @@ test_that("emuRtrackdata functions work", {
   
   test_that("normalize_length returns normalized segments on tibble", {
 
-    sl = query(ae, "Phonetic = I", resultType = "tibble")
+    sl = query(ae, "Phonetic = I", 
+               resultType = "tibble")
     td = get_trackdata(ae,
                        seglist = sl,
                        ssffTrackName = 'fm',
